==> jc-1.4.0.tar.gz: gnu/xml/pipeline/PipelineFactory__24Stage.h <==
// class gnu.xml.pipeline.PipelineFactory$Stage

// class file dependencies
// @dep_class 489e83307f919d3e gnu_xml_pipeline_PipelineFactory__24Stage
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_PipelineFactory__24Stage_H_
#define _JC_gnu_xml_pipeline_PipelineFactory__24Stage_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$object;

typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype;

// Class fields structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24xml__24pipeline__24EventConsumer;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
};
extern _jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$class_fields;

// Constructors
extern void _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$createStage$b401c9f2b2de2124(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_object *);
extern void _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$fail$2bbd7a44d48fc628(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method_info$createStage$b401c9f2b2de2124;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method_info$fail$2bbd7a44d48fc628;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods {
	struct _jc_object	*(*createStage$b401c9f2b2de2124)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_object *);
	void	(*fail$2bbd7a44d48fc628)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods	gnu_xml_pipeline_PipelineFactory__24Stage;
};

// Vtype
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs {
	struct _jc_java_lang_String$object	*id;
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*param;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs {
    _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs	gnu_xml_pipeline_PipelineFactory__24Stage;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs	gnu_xml_pipeline_PipelineFactory__24Stage;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object {
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype	*vtype;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype _jc_gnu_xml_pipeline_PipelineFactory__24Stage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_PipelineFactory__24Stage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_PipelineFactory__24Stage$class_object;

#endif	/* _JC_gnu_xml_pipeline_PipelineFactory__24Stage_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/PipelineFactory__24Stage.h <==
// class gnu.xml.pipeline.PipelineFactory$Stage

// class file dependencies
// @dep_class 489e83307f919d3e gnu_xml_pipeline_PipelineFactory__24Stage
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_PipelineFactory__24Stage_H_
#define _JC_gnu_xml_pipeline_PipelineFactory__24Stage_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$object;

typedef struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype;

// Class fields structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24xml__24pipeline__24EventConsumer;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
};
extern _jc_gnu_xml_pipeline_PipelineFactory__24Stage$fields_struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$class_fields;

// Constructors
extern void _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$createStage$b401c9f2b2de2124(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$fail$2bbd7a44d48fc628(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method_info$createStage$b401c9f2b2de2124;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method_info$fail$2bbd7a44d48fc628;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory__24Stage$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_xml_pipeline_PipelineFactory__24Stage$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods {
	struct _jc_object	*(*createStage$b401c9f2b2de2124)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*fail$2bbd7a44d48fc628)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vmethods	gnu_xml_pipeline_PipelineFactory__24Stage;
};

// Vtype
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs {
	struct _jc_java_lang_String$object	*id;
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*param;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs {
    _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_refs	gnu_xml_pipeline_PipelineFactory__24Stage;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_PipelineFactory__24Stage$sub_nonrefs	gnu_xml_pipeline_PipelineFactory__24Stage;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object {
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype	*vtype;
	_jc_gnu_xml_pipeline_PipelineFactory__24Stage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_PipelineFactory__24Stage$vtype _jc_gnu_xml_pipeline_PipelineFactory__24Stage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_PipelineFactory__24Stage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_PipelineFactory__24Stage$class_object;

#endif	/* _JC_gnu_xml_pipeline_PipelineFactory__24Stage_H_ */
